==> drools-wb-7.4.1.Final-project-sources.tar.gz: drools-wb-7.4.1.Final/drools-wb-screens/drools-wb-globals-editor/drools-wb-globals-editor-api/src/main/java/org/drools/workbench/screens/globals/type/GlobalResourceTypeDefinition.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.drools.workbench.screens.globals.type;

import javax.enterprise.context.ApplicationScoped;

import org.uberfire.backend.vfs.Path;
import org.uberfire.workbench.type.ResourceTypeDefinition;

@ApplicationScoped
public class GlobalResourceTypeDefinition implements ResourceTypeDefinition {

    @Override
    public String getShortName() {
        return "global";
    }

    @Override
    public String getDescription() {
        return "Globals definition";
    }

    @Override
    public String getPrefix() {
        return "";
    }

    @Override
    public String getSuffix() {
        return "gdrl";
    }

    @Override
    public int getPriority() {
        return 101;
    }

    @Override
    public String getSimpleWildcardPattern() {
        return "*." + getSuffix();
    }

    @Override
    public boolean accept( final Path path ) {
        return path.getFileName().endsWith( "." + getSuffix() );
    }
}

==> drools-wb-7.7.0.Final-project-sources.tar.gz: drools-wb-7.7.0.Final/drools-wb-screens/drools-wb-globals-editor/drools-wb-globals-editor-api/src/main/java/org/drools/workbench/screens/globals/type/GlobalResourceTypeDefinition.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.workbench.screens.globals.type;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.guvnor.common.services.project.categories.Decision;
import org.uberfire.backend.vfs.Path;
import org.uberfire.workbench.category.Category;
import org.uberfire.workbench.type.ResourceTypeDefinition;

@ApplicationScoped
public class GlobalResourceTypeDefinition implements ResourceTypeDefinition {

    private Category category;

    public GlobalResourceTypeDefinition() {
    }

    @Inject
    public GlobalResourceTypeDefinition(final Decision category) {
        this.category = category;
    }

    @Override
    public Category getCategory() {
        return this.category;
    }

    @Override
    public String getShortName() {
        return "global";
    }

    @Override
    public String getDescription() {
        return "Globals definition";
    }

    @Override
    public String getPrefix() {
        return "";
    }

    @Override
    public String getSuffix() {
        return "gdrl";
    }

    @Override
    public int getPriority() {
        return 101;
    }

    @Override
    public String getSimpleWildcardPattern() {
        return "*." + getSuffix();
    }

    @Override
    public boolean accept(final Path path) {
        return path.getFileName().endsWith("." + getSuffix());
    }
}
